@@ -237,14 +237,23 @@ class InstanceValidation(BasicValidation):
         # Свойство предназначенное для замены словаря
         self._replacement = None
 
+    def _try_replacing(self) -> None:
+        """
+            Пытается заменить значение у текущего поля на текущее значение
+            свойства self._replacement.
+        """
+        # Если включен флаг замены и есть чем заменять, то установим
+        # новое значение у поля
+        if self._replace and self._replacement is not None:
+            setattr(self, self._field_name, self._replacement)
+
     def _is_field_valid(self, field: DataclassesField) -> bool:
 
         result = super()._is_field_valid(field)
 
-        # Если включен флаг замены и валидация поля прошла успешно и
-        # есть чем заменять, то установим новое значение у поля
-        if self._replace and result and self._replacement is not None:
-            setattr(self, self._field_name, self._replacement)
+        if result:
+            # Попробуем произвести замену
+            self._try_replacing()
 
         return result
 
@@ -386,9 +395,9 @@ class TypingValidation(InstanceValidation):
                     new_value.append(item_value)
                 else:
                     self._field_errors.append(ListValidationError(
-                            value_repr=get_value_repr(item_value),
-                            value_type=type(item_value), item_index=i,
-                            annotation=annotation, exception=None
+                        value_repr=get_value_repr(item_value),
+                        value_type=type(item_value), item_index=i,
+                        annotation=annotation, exception=None
                     ))
                     return False
 
@@ -398,8 +407,8 @@ class TypingValidation(InstanceValidation):
         else:
             # Значение поля - не список, а это ошибка валидации
             self._field_errors.append(BasicValidationError(
-                    value_repr=get_value_repr(value), value_type=type(value),
-                    annotation=annotation, exception=None
+                value_repr=get_value_repr(value), value_type=type(value),
+                annotation=annotation, exception=None
             ))
             return False
 
@@ -413,8 +422,8 @@ class TypingValidation(InstanceValidation):
 
         if not result:
             self._field_errors.append(LiteralValidationError(
-                    value_repr=get_value_repr(value), value_type=type(value),
-                    annotation=annotation, exception=None
+                value_repr=get_value_repr(value), value_type=type(value),
+                annotation=annotation, exception=None
             ))
 
         return result
